from .RuntimeCtx import RuntimeCtx, RuntimeCtxNamespace
from .StorageDelegate import StorageDelegate
from .PluginManager import PluginManager
from .AliasManager import AliasManager
from .IdGenerator import IdGenerator
from .DataOps import DataOps, NamespaceOps
from .transform import to_json_desc, to_instruction, find_all_jsons, find_json
from .check_version import check_version


#ABC = Abstract Base Class
from abc import ABC, abstractmethod

class SkillABC(ABC):
    def __init__(self, request):
        self.request = request

    @abstractmethod
    def export(self):
        return {
            "generate_request_data": callable,# (get_settings, request_runtime_ctx) -> request_data: dict
            "request_model": callable,# (request_data) -> response_generator
            "broadcast_response": callable,# (response_generator) -> broadcast_event_generator
        }


from .utils import ComponentABC

class Skill(ComponentABC):
    def __init__(self, agent):
        self.agent = agent

    def must_use(self, skill_name_list: (str, list)):
        plugin_manager = self.agent.plugin_manager

    def may_use(self, skill_name_list: (str, list)):
        pass

    def export(self):
        return {
            "prefix": None,
            "suffix": None,
            "alias": {},
        }

def export():
    return ("Skill", Skill)